Flask-WebTest
=============

.. image:: https://dl.circleci.com/status-badge/img/gh/level12/flask-webtest/tree/master.svg?style=svg
        :target: https://dl.circleci.com/status-badge/redirect/gh/level12/flask-webtest/tree/master

Flask-WebTest provides a set of utilities to ease testing Flask applications with WebTest.

As a small-in-scope project and relatively mature/stable, lack of recent commits does not indicate
it is abandoned. Occasionally, Flask or another dependency will deprecate imports. Most updates
here will be to resolve those breakages when they occur.


Installation
------------

``pip install flask-webtest``

Documentation
-------------

Documentation is available on `Read the Docs`_.

.. _Read the Docs: https://flask-webtest.readthedocs.org/en/latest/
